@@ -3,14 +3,30 @@
 normalize<-function(lambda,X,nobj,ENV){
 
    nrm<-function(r,eta,Bstar,alpha,betas,Xundec,XIthet,ENV){   # 7.12.09  Xundec added
-      if(ENV$MISalpha){
-        rBstar<-r %*% Bstar                  # one row of RBstar, identical for all rows within block
-        eta<-eta + as.vector(rBstar[,ENV$Malph]%*%alpha) # scalar, based on one row of RBstar,
-                                             # identical for all rows within block
+
+      #####    nonresponse models alpha_i+alpha_j/alpha_i-alpha_j
+      if (ENV$MISmod=="obj"){    # 6.9.2010
+
+          if(ENV$MISalpha){
+            rBstar<-r %*% Bstar                  # one row of RBstar, identical for all rows within block
+            eta<-eta + as.vector(rBstar[,ENV$Malph]%*%alpha) # scalar, based on one row of RBstar,
+                                                 # identical for all rows within block
+          }
+          if (ENV$MISbeta){
+            YrBstar<-do.call(cbind,lapply(1:nobj,function(x)ENV$Y[,x]*rBstar[x])) # design matrix for betas for current block
+            eta<-eta+YrBstar[,ENV$Mbeta,drop=FALSE]%*%betas # 27.6.2010
+          }
       }
-      if (ENV$MISbeta){
-        YrBstar<-do.call(cbind,lapply(1:nobj,function(x)ENV$Y[,x]*rBstar[x])) # design matrix for betas for current block
-        eta<-eta+YrBstar[,ENV$Mbeta,drop=FALSE]%*%betas # 27.6.2010
+
+      #####    nonresponse model alpha_ij  # 6.9.2010
+      if (ENV$MISmod=="comp"){
+          if(ENV$MISalpha)
+             eta <- eta + as.vector(r[ENV$Malph]%*%alpha)
+          if (ENV$MISbeta){
+             Yr<-ENV$Y[,ENV$Mbeta,drop=FALSE] * r[ENV$Mbeta]
+             ####Yr<-do.call(cbind,lapply((1:nobj,function(x)ENV$Y[,x]*r[x])) # design matrix for betas for current block
+             eta <- eta + Yr%*%betas
+          }
       }
 
       if(ENV$undec){                 # 7.12.09
